using System;
using Server.Mobiles;

namespace Server.Items
{
	public class ShadowInfectiousStrike : WeaponAbility
	{
		public ShadowInfectiousStrike(){}

		public override int BaseMana{ get{ return 25; } }

		public override void OnHit( Mobile attacker, Mobile defender, int damage )
		{
			if ( !Validate( attacker ) ) return;
			ClearCurrentAbility( attacker );
			BaseWeapon weapon = attacker.Weapon as BaseWeapon;
			if ( weapon == null ) return;
			Skill skill = attacker.Skills[SkillName.Stealth];
			Poison p = weapon.Poison;
			bool canpoison = true;
			bool canhide = true;
			if ( (p == null || weapon.PoisonCharges <= 0) && ((skill != null && skill.Value < 80.0) || skill == null ) )
			{
				attacker.SendMessage( "Not enough Stealth for the Hiding, and the weapon is out of Poison, so you are out of luck" );
				return;
			}
			if ( (p == null || weapon.PoisonCharges <= 0) && (skill != null && skill.Value >= 80.0) )
			{
				attacker.SendMessage( "No Poison left, but still Hiding" );
				canpoison = false;
			}
			if ( (p != null && weapon.PoisonCharges > 1) && ((skill != null && skill.Value < 80.0) || skill == null ) )
			{
				attacker.SendMessage( "Not enough Stealth for the Hiding, but still Poisoning" );
				canhide = false;
			}
			if (canpoison)
			{
				if ( !CheckMana( attacker, true ) ) return;
				--weapon.PoisonCharges;
				int maxLevel = attacker.Skills[SkillName.Poisoning].Fixed / 200;
				if ( maxLevel < 0 ) maxLevel = 0;
				if ( p.Level > maxLevel ) p = Poison.GetPoison( maxLevel );
				if ( (attacker.Skills[SkillName.Poisoning].Value / 100.0) > Utility.RandomDouble() )
				{
					int level = p.Level + 1;
					Poison newPoison = Poison.GetPoison( level );
					if ( newPoison != null )
					{
						p = newPoison;
						attacker.SendLocalizedMessage( 1060080 );
						defender.SendLocalizedMessage( 1060081 );
					}
				}
				if ( attacker is PlayerMobile && ((PlayerMobile)attacker).isRogue )
				{
					int level = p.Level + 1;
					if ( level > 5 ) level = 5;
					Poison newPoison = Poison.GetPoison( level );
					if ( newPoison != null )
					{
						p = newPoison;
						attacker.SendLocalizedMessage( 1060080 );
						defender.SendLocalizedMessage( 1060081 );
					}
				}
				defender.PlaySound( 0xDD );
				defender.FixedParticles( 0x3728, 244, 25, 9941, 1266, 0, EffectLayer.Waist );
				if ( defender.ApplyPoison( attacker, p ) != ApplyPoisonResult.Immune )
				{
					attacker.SendLocalizedMessage( 1008096, true, defender.Name );
					defender.SendLocalizedMessage( 1008097, false, attacker.Name );
				}
			}
			if (canhide)
			{
				defender.SendLocalizedMessage( 1060079 );
				Effects.SendLocationParticles( EffectItem.Create( attacker.Location, attacker.Map, EffectItem.DefaultDuration ), 0x376A, 8, 12, 9943 );
				attacker.PlaySound( 0x482 );
				defender.FixedEffect( 0x37BE, 20, 25 );
				if ( attacker is PlayerMobile)
				{
					PlayerMobile mm = attacker as PlayerMobile;
					if ( mm.is1Death_Knight || mm.isRogue ||  mm.isTomb_Raider )
					{
						attacker.SendMessage( "You also strike for extra damage"  );
						defender.SendMessage( "He knew right where to hit you for extra damage" );
						int i_ClassLevel = mm.ClassLevel;
						int i_ExtraDam = (int)(i_ClassLevel);
						if ( i_ExtraDam >= 100) i_ExtraDam = 100;
						defender.Hits -= i_ExtraDam;
					}
				}
				attacker.Combatant = null;
				attacker.Warmode = false;
				attacker.Hidden = true;
			}
		}
	}
}